# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import inspect


def get_tests_ids_to_run(
        config_stack, tests_module=None, testsuite_list_filepath=None):
    """Return a list of the test ids to run in the test bed.

    :param tests_module: The module that contains the Ubuntu System Tests.
        Default value is ubuntu_system_tests.tests. Currently, a value other
        than the default is used only for self-testing.

    """
    tests_from_config = config_stack.get('tests_to_run', None)
    if tests_from_config:
        return tests_from_config.split()

    # If we do this at the module level then we need to have unity8 and UITK on
    # the host and would rather avoid this
    from ubuntu_system_tests import external_tests
    test_ids = external_tests.get_external_test_ids(testsuite_list_filepath)

    if tests_module is None:
        # We delay the import so this is only executed in the test bed, not on
        # the host which might have a different version of the libraries used
        # in the system tests.
        from ubuntu_system_tests import tests
        tests_module = tests

    if inspect.ismodule(tests_module):
        test_ids.append(tests_module.__name__)

    return test_ids
