# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures
import glob
import os
import socket

from ubuntu_system_tests.helpers.backup_restore_fixture import (
    BackupRestoreFixture)
from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers import wait_until

DIR_HOME_CALENDAR_TASKS = os.path.join(fs.DIR_HOME_LOCAL, 'share',
                                       'evolution', 'tasks')
EVOLUTION_PROCESS = 'evolution-calendar-factory'
INDICATOR_PROCESS = 'indicator-datetime-service'


def _stop_and_wait_process(pname):
    processes.stop_process(pname)
    wait_until(processes.is_process_running, pname)


def _get_task_dirs():
    return glob.glob(DIR_HOME_CALENDAR_TASKS + '/*@' + socket.gethostname())


def _clean_tasks_dir():
    tasks_dir = _get_task_dirs()
    if tasks_dir:
        fs.remove_dir(tasks_dir[0])


class BackupRestoreCalendarFixture(fixtures.Fixture):
    """
    Backup and restore the tasks dir to keep the initial calendar configuration
    """

    def setUp(self):
        super().setUp()

        self.addCleanup(_stop_and_wait_process, INDICATOR_PROCESS)
        self.addCleanup(processes.stop_process, EVOLUTION_PROCESS)

        tasks_dir = _get_task_dirs()
        if tasks_dir:
            self.useFixture(BackupRestoreFixture(tasks_dir[0]))
            processes.stop_process(EVOLUTION_PROCESS)
            _stop_and_wait_process(INDICATOR_PROCESS)
        else:
            self.addCleanup(_clean_tasks_dir)
