# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import json
import os

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import file_system as fs


class DeviceMetadata:
    """ Device Metadata Object """

    def __init__(self, id, front_camera, rear_camera):
        self.id = id or ""
        self.front_camera = CameraMetadata.from_dict(front_camera) or None
        self.rear_camera = CameraMetadata.from_dict(rear_camera) or None

    @staticmethod
    def from_dict(dic):
        """ Retrieve a class object based on a dict """
        return DeviceMetadata(dic['id'],
                              dic['front_camera'],
                              dic['rear_camera'])


class CameraMetadata:
    """ Camera Metadata Object """

    def __init__(self, width, height):
        self.width = width or 0
        self.height = height or 0

    @staticmethod
    def from_dict(dic):
        """ Retrieve a class object based on a dict """
        return CameraMetadata(dic['width'],
                              dic['height'])


def get_current_device_metadata():
    """ Retrieve the device metadata object for the current device """
    global device_metadata
    if device_metadata:
        return device_metadata

    device_id = autopilot.get_device_name()
    data_file = os.path.join(fs.DIR_TEST_DATA_DEVICES, device_id + '.json')

    if not os.path.isfile(data_file):
        raise RuntimeError("Metadata file {} does not exist".format(data_file))

    with open(data_file) as f:
        device_metadata = DeviceMetadata.from_dict(json.load(f))
        return device_metadata


device_metadata = None
