# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import dialer_app

from autopilot import introspection

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase

logger = logging.getLogger(__name__)


class DialerApp(UbuntuUIToolkitCustomProxyObjectBase):

    """Autopilot custom proxy object for the dialer app."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        name = introspection.get_classname_from_path(path)
        return (name == b'DialerApp' and
                state['applicationName'][1] == 'DialerApp')

    @property
    def main_view(self):
        return self.select_single(MainView, objectName='mainView')


class MainView(dialer_app.MainView):

    @property
    def dialer_page(self):
        return self.wait_select_single(
            DialerPage, objectName='dialerPage', visible=True)


class LiveCall(dialer_app.LiveCall):

    def get_stop_watch(self):
        """Return the stop watch object"""
        return self.wait_select_single(
            StopWatch, objectName='stopWatch', visible=True)


class StopWatch(UbuntuUIToolkitCustomProxyObjectBase):

    def elapsed_time(self):
        """Return elapsed time as string"""
        return self.elapsed


class DialerPage(dialer_app.DialerPage):

    def _get_phone_number_input(self):
        """Return PhoneNumberInput object"""
        return self.select_single('PhoneNumberInput', visible=True)

    def get_entered_phone_number(self):
        """Return the phone number entered into the dialer"""
        return self._get_phone_number_input().displayText
