# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures

from dialer_app.fixture_setup import UseEmptyHistory

from ubuntu_system_tests.helpers.system_settings import (
    get_default_sim_for_calls, set_default_sim_for_calls)


class DialerTestEnvironment(fixtures.Fixture):
    """Fixture used to prepare the phone environment"""

    def setUp(self):
        super().setUp()
        self.useFixture(SetDefaultSIM())
        self.useFixture(UseEmptyHistory())


class SetDefaultSIM(fixtures.Fixture):
    """
    Fixture to set the default sim for calls.

    """

    def __init__(self, sim='1'):
        """
        Specify what sim to set.

        :param sim: '1', '2' or 'ask'

        """
        super().__init__()
        self.sim = sim

    def setUp(self):
        super().setUp()
        original_value = get_default_sim_for_calls()
        self.addCleanup(set_default_sim_for_calls, original_value)
        set_default_sim_for_calls(self.sim)
