# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from gallery_app.emulators import events_view, photo_viewer
from gallery_app.emulators.gallery_utils import GalleryAppException


class EventsView(events_view.EventsView):

    def is_image_displayed(self, image_name):
        try:
            return self._get_image_in_event_view(image_name) is not None
        except GalleryAppException:
            return False

    def pick_photo(self, file_path):
        """
        Picks the requested photo to be consumed by the requester

        :param file_path: identifier for the photo to pick
        """
        self._select_photo(file_path)
        self._click_pick_button()

    def _select_photo(self, file_path):
        """Selects a photo in EventView by long press."""
        photo = self._get_image_in_event_view(file_path)
        self.pointing_device.click_object(photo, press_duration=1)

    def _get_header_pick_button(self):
        """Returns the validate/pick button on the toolbar."""
        return self.get_qml_view().select_single(
            objectName='pickButton_header_button')

    def _click_pick_button(self):
        """Taps the pick button in the header."""
        button = self._get_header_pick_button()
        self.pointing_device.click_object(button)


class PhotoViewer(photo_viewer.PhotoViewer):

    def get_opened_photo(self):
        """Returns the first visible opened photo."""
        return self.app.wait_select_single("SingleMediaViewer",
                                           objectName="openedMedia0",
                                           visible=True)

    def _get_image(self):
        """Return the visible (also opaque) QQuickImage."""
        photo = self.get_opened_photo()
        # companion QQuickImage has opacity 0.0
        return photo.wait_select_single(type_name='QQuickImage', visible=True,
                                        opacity=1.0)

    def get_image_source(self):
        return self._get_image().source
