# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures
import os

from unity8.process_helpers import start_job, stop_job, is_job_running

from ubuntu_system_tests.helpers import backup_restore_fixture as brf
from ubuntu_system_tests.helpers.file_system import get_media_folder_list
from ubuntu_system_tests.helpers.unity8.dash import get_dash

MEDIA_SCANNER = 'mediascanner-2.0'


def restart_media_scanner():
    """Restart the media scanner process."""
    if is_job_running(MEDIA_SCANNER):
        stop_job(MEDIA_SCANNER)
    start_job(MEDIA_SCANNER)
    dash = get_dash()
    dash.wait_for_dash_loaded()
    dash.wait_for_processing_to_complete()


class BackupRestoreLocalMediaFixture(fixtures.Fixture):
    """Generic fixture class to backup and restore all local media files."""

    def __init__(self, start_clean=True):
        """
        :param start_clean: Whether to clean media directories after backup.

        """
        self.start_clean = start_clean

    def setUp(self):
        """Backup the required directory and register restore actions."""
        super().setUp()
        self._backup_local_media()

    def _backup_local_media(self):
        """Backup the local media files which are removed during testing."""
        for folder in get_media_folder_list():
            if folder.startswith('/media/'):
                backup_path = os.path.join(
                    os.path.dirname(folder), '.tmp_backup')
            else:
                backup_path = os.path.expanduser('~/.tmp_backup')
            self.useFixture(brf.BackupRestoreFixture(
                folder, storage_root_dir=backup_path,
                start_clean=self.start_clean))
