# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from collections import namedtuple
from math import ceil

# Number of characters sent in a single SMS message
SMS_MESSAGE_SIZE = 153

Message = namedtuple('Message', ['body', 'attachments'])
Message.__new__.__defaults__ = (None, [])

Attachment = namedtuple('Attachment', ['attach_method', 'identifier'])
Attachment.__new__.__defaults__ = (None, None)

Search = namedtuple('Search',
                    ['query', 'expected_thread_count',
                     'expected_thread_number'])
Search.__new__.__defaults__ = (None, None, None)


def calculate_sent_message_count(body, size=SMS_MESSAGE_SIZE):
    """
    Calculate the number of sms messages required to send the message.

    :param body: The message body
    :param size: Size in characters of the required message chunks
    :return: Number of messages required to send message body

    """
    return ceil(len(body) / size)


def split_into_received_messages(body, concatenate, size=SMS_MESSAGE_SIZE):
    """
    Break down the specified message into messages that are received by the
    telephony service.

    If concatenate is True then body will be returned as 1 single
    chunk. If concatenate is False then body will be broken down into
    multiple message chunks of specified size.

    :param body: The message body to split into chunks
    :param concatenate: Indicate whether sms concatentation is supported by the
                        receiver
    :param size: Size in characters of the required message chunks
    :return: List of messages of specified size

    """
    if concatenate:
        return [body]
    return [body[pos:size+pos] for pos in range(0, len(body), size)]
