# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import subprocess
from urllib import request

from ubuntu_system_tests.helpers import wait_until


def check_connection(host):
    """Try to connect to the requested host and return True if successful,
    otherwise return False."""
    try:
        request.urlopen(host, timeout=1)
        return True
    except request.URLError:
        return False


def turn_on_wifi():
    """Turn on wifi from command line."""
    subprocess.call(['rfkill', 'unblock', 'wlan'])


def turn_off_wifi():
    """Turn off wifi from command line."""
    subprocess.call(['rfkill', 'block', 'wlan'])


def turn_on_data_connection():
    """Turn on data connection from command line."""
    _run_system_command_no_stdout('/usr/share/ofono/scripts/enable-gprs')


def turn_off_data_connection():
    """Turn off data connection from command line."""
    _run_system_command_no_stdout('/usr/share/ofono/scripts/disable-gprs')


def _run_system_command_no_stdout(cmd):
    """Run the given command with subprocess and divert the stdout to
    /dev/null."""
    dev_null = open(os.devnull, 'w')
    subprocess.call(cmd.split(), stdout=dev_null, stderr=subprocess.STDOUT)


def ensure_internet_connectivity(timeout):
    """Wait for internet availability for the specified time, else
    fail the test."""
    host = 'http://ubuntu.com'
    return wait_until(check_connection, timeout=timeout, period=1, host=host)
