# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import autopilot

from ubuntu_system_tests.helpers.notifications import NotificationBase

logger = logging.getLogger(__name__)

BUTTON_OPEN = 'Open'
BUTTON_DISMISS = 'Dismiss'
BUTTONS = [BUTTON_OPEN, BUTTON_DISMISS]


def validate(notification):
    """
    Return True if notification object is valid and looks like a download
    complete notification.

    Note this is implemented as a static method because it is reliable
    in cases where multiple notifications are displayed and autopilot CPO
    inheritance fails.

    :param notification: The notification object to validate.

    """
    if notification:
        try:
            return (notification.validate_buttons(BUTTONS) and
                    notification.has_icon() and
                    notification.summary == 'Download Complete')
        except autopilot.exceptions.StateNotFoundError:
            pass
    return False


class Notification(NotificationBase):

    def get_open_button(self):
        return self.get_button(text=BUTTON_OPEN, objectName='notify_button0')

    def get_dismiss_button(self):
        return self.get_button(
            text=BUTTON_DISMISS, objectName='notify_button1')

    @autopilot.logging.log_action(logger.info)
    def open(self):
        self.pointing_device.click_object(self.get_open_button())

    @autopilot.logging.log_action(logger.info)
    def dismiss(self):
        self.pointing_device.click_object(self.get_dismiss_button())
