# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import autopilot

from ubuntu_system_tests.helpers.notifications import NotificationBase
from ubuntu_system_tests.helpers.notifications.swiper import SwipeToAct

logger = logging.getLogger(__name__)

BUTTONS = []


def validate(notification):
    """
    Return True if notification object is valid and looks like an incoming call
    notification.

    Note this is implemented as a static method because it is reliable
    in cases where multiple notifications are displayed and autopilot CPO
    inheritance fails.

    :param notification: The notification object to validate.

    """
    if notification:
        try:
            return (notification.secondaryIconSource ==
                    'image://theme/incoming-call' and
                    notification.body.startswith('Calling from'))
        except autopilot.exceptions.StateNotFoundError:
            pass
    return False


class Notification(NotificationBase):

    @autopilot.logging.log_action(logger.info)
    def start_call(self):
        self._get_swiper().swipe_to_right()

    @autopilot.logging.log_action(logger.info)
    def end_call(self):
        self._get_swiper().swipe_to_left()

    def get_caller_name(self):
        return self.summary

    def get_caller_message(self):
        return self.body

    def _get_swiper(self):
        return self.select_single(SwipeToAct, visible=True)

    def dismiss(self):
        self.end_call()
