# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import subprocess
import shlex

import fixtures


class BrightnessEnvironmentFixture(fixtures.Fixture):

    def __init__(self, auto_brightness='disable', brightness_value=255):
        self.auto_brightness = auto_brightness
        self.brightness_value = str(brightness_value)

    def setUp(self):
        super().setUp()
        self.useFixture(AutoBrightness(state=self.auto_brightness))
        self.useFixture(Brightness(value=self.brightness_value))


def _get_auto_brightness_current_setting():
    """Return current auto brightness state from gsettings."""
    command = 'gsettings get com.ubuntu.touch.system auto-brightness'
    return subprocess.check_output(shlex.split(command),
                                   universal_newlines=True).strip()


def _set_auto_brightness_setting(value):
    """Change auto brightness from gsettings."""
    command = 'gsettings set com.ubuntu.touch.system ' \
              'auto-brightness {}'.format(value)
    return subprocess.check_call(shlex.split(command))


class AutoBrightness(fixtures.Fixture):

    def __init__(self, state):
        self.request = state

    def setUp(self):
        super().setUp()
        old_value = _get_auto_brightness_current_setting()
        self.addCleanup(_set_auto_brightness_setting, old_value)

        if self.request == 'enable':
            _set_auto_brightness_setting('true')
        elif self.request == 'disable':
            _set_auto_brightness_setting('false')


def _set_brightness_value(value):
    """Set brightness through powerd, should be between 10 and 255."""
    command = 'powerd-cli brightness {}'.format(value)
    subprocess.check_call(shlex.split(command),
                          stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)


def _get_current_brightness():
    """Return the current brightness value."""
    command = 'gsettings get com.ubuntu.touch.system brightness'
    return subprocess.check_output(shlex.split(command),
                                   universal_newlines=True).strip()


class Brightness(fixtures.Fixture):
    """Fixture to set custom screen brightness."""

    def __init__(self, value):
        self.value = value

    def setUp(self):
        super().setUp()
        old_value = _get_current_brightness()
        _set_brightness_value(self.value)
        self.addCleanup(_set_brightness_value, old_value)
