# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
import os
import signal
import subprocess

logger = logging.getLogger(__name__)


def is_process_running(pname):
    try:
        return get_process_id(pname) != 0
    except:
        return False


def get_process_id(pname):
    return int(subprocess.check_output(['pidof', pname]))


def stop_process(pname):
    if is_process_running(pname):
        pid = get_process_id(pname)
        os.kill(pid, signal.SIGKILL)


def ensure_application_closed(app_name):
    subprocess.call(['ubuntu-app-stop', app_name])


def is_qmlscene_running_with_qmlfile(qmlfile):
    """ Indicate if the qmlscene is running the qml file qmlfile """
    pline = subprocess.check_output('ps -ef | grep qmlscene', shell=True,
                                    universal_newlines=True)
    return qmlfile in pline


def get_qmlscene_process_id(qmlfile):
    """ Retrieve the process id for the qmlscene running the file qmlfile """
    pline = subprocess.check_output(
        'ps -ef | grep qmlscene | grep {}'.format(qmlfile), shell=True,
        universal_newlines=True)
    return int(pline.split()[1])


def stop_qmlscene_process(qmlfile):
    """ Stop the qmlscene process running the file qmlfile """
    if is_qmlscene_running_with_qmlfile(qmlfile):
        pid = get_qmlscene_process_id(qmlfile)
        os.kill(pid, signal.SIGKILL)


def get_process_args(pid):
    """ Retrieve the command line used to start the process """
    return subprocess.check_output('xargs -0 < /proc/{}/cmdline'.format(pid),
                                   shell=True, universal_newlines=True)
