# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot import exceptions

from ubuntu_system_tests.helpers.scopes import Scope

APP_STORE_TITLE = 'Ubuntu Store'


class AppsScope(Scope):

    def open_app_store(self):
        """Press the app store icon to load the apps store."""
        self.scope.pointing_device.click_object(self.get_app_store_icon())
        self.wait_for_processing_to_complete()

    def get_app_store_icon(self):
        """Return the app store icon from the apps scope."""
        return self.scope.select_single('AbstractButton', title='Ubuntu Store')

    def is_app_displayed(self, app_name):
        """Return True if app with specified name is displayed."""
        try:
            self.scope.get_root_instance().wait_select_single(
                'AbstractButton', objectName='delegate0', title=app_name)
            return True
        except exceptions.StateNotFoundError:
            return False
