# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import subprocess
import shutil


from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers import testbed


def remove():
    """
    Simulate a physical removal of the sd card by unmounting the device using
    the udisksctl command
    :return: the device path that has been removed, i.e. /dev/mmcblk1p1
    """
    device = get_sd_card_device()
    subprocess.check_output('udisksctl unmount -f -b {}'.format(device),
                            shell=True)
    return device


def insert(device):
    """
    Simulate a physical insertion of the sd card by mounting the device
    using the udisksctl command
    :param device: the device path that has been inserted, i.e. /dev/mmcblk1p1
    """
    if not is_device_mounted(device):
        command = 'udisksctl'
        args = ['mount', '-b', device]
        testbed.run_command_with_password_prompt(command, args,
                                                 password_pattern='Password:')


def is_device_mounted(device):
    output = subprocess.check_output('mount -l', shell=True,
                                     universal_newlines=True)
    return device in output


def get_sd_card_device():
    """ Retrieve the device path for the sd card inserted """
    dirname = get_sd_card_dir_name()
    command = 'mount -l | grep {}'.format(dirname)
    output = subprocess.check_output(command, shell=True,
                                     universal_newlines=True)
    if output:
        return output.split()[0]
    else:
        raise RuntimeError('SD CARD device not detected')


def get_sd_card_dir_name():
    dir = fs.get_media_folder_dir(fs.DIR_MUSIC)
    return dir.split('/')[-2]


def copy_music(src_path):
    """ Copy the src music file to the music directory in the sd card """
    filename = os.path.basename(src_path)
    dst_path = os.path.join(fs.get_media_folder_dir(fs.DIR_MUSIC), filename)
    shutil.copy2(src_path, dst_path)
