# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import threading


class StoppingThread(threading.Thread):
    """A Thread class which can be signalled to stop using stop() method."""

    def __init__(self, *args, **kwargs):
        """Create an Event object to wait for notification of when to stop."""
        super().__init__(*args, **kwargs)
        self._stop_event = threading.Event()

    def stop(self):
        """Set _stop_event to signal that the thread should stop."""
        self._stop_event.set()

    def run(self):
        """Launch the target function including the _stop_event parameter."""
        self._target(self._stop_event, *self._args, **self._kwargs)
