# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from datetime import datetime
import os

TIME_FORMAT_RFC_2822 = '%a, %d %b %Y %H:%M:%S +0000'


def get_current_day_of_month():
    """Return current day of month 0-31."""
    return datetime.now().strftime('%d')


def get_current_day_name():
    """Return current day name."""
    return datetime.now().strftime('%A')


def get_current_month_name():
    """Return current month name."""
    return datetime.now().strftime('%B')


def get_current_week_number():
    """Return current week number."""
    return str(int(datetime.now().strftime('%W')) + 1)


def get_current_utc_time(format_string=TIME_FORMAT_RFC_2822):
    """
    Return the current UTC time.

    Default behaviour is to return time in rfc 2822 format:
    example: Mon, 10 Aug 2015 15:52:01 +0000

    :param format_string: String representation of required time format.

    """
    return datetime.utcnow().strftime(format_string)


def _get_date(path, date_method):
    """ Retrieve the datetime requested for file/dir
    :param path: path to the file
    :param date_method: method that will retrieve the desired timestamp
    """
    if not os.path.exists(path):
        raise RuntimeError("File to retrieve date does not exist")

    return datetime.fromtimestamp(date_method(path))


def _get_utc_date(path, date_method):
    """ Retrieve the utc datetime requested for file/dir """
    time_offset = datetime.utcnow() - datetime.now()
    return _get_date(path, date_method) - time_offset


def get_utc_last_access_time(path):
    """ Retrieve a datetime with the utc last access time for a file/dir """
    return _get_utc_date(path, os.path.getatime)


def get_utc_last_modification_time(path):
    """
    Retrieve a datetime with the utc last modification time for a file/dir
    """
    return _get_utc_date(path, os.path.getmtime)
