
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from autopilot import introspection
from ubuntuuitoolkit._custom_proxy_objects._qquicklistview import QQuickListView  # NOQA


class QQuickListView(QQuickListView):
    """Extend QQuickListView from Ubuntu UI Toolkit."""

    def _swipe_to_label(self, label_text):
        """Swipe the required label into view on the provided list"""
        self.swipe_to_top()
        done_first_search = False
        while not done_first_search or not self.atYEnd:
            try:
                item = self.select_single(
                    'Label', text=label_text, visible='True')
                item.swipe_into_view()
                return item
            except introspection.dbus.StateNotFoundError:
                self.swipe_to_show_more_below()
            done_first_search = True
        # item could not be found
        raise introspection.dbus.StateNotFoundError

    def get_label(self, text):
        """Swipe to the label with specified text and return Label object."""
        return self._swipe_to_label(text)

    def press_label(self, text):
        """
        Press label with specified text in the indicator's list view.
        This will swipe the required item into view if it is not currently
        displayed.

        """
        self.pointing_device.click_object(self.get_label(text))
