
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase

from ubuntu_system_tests.helpers.autopilot import order_by_y_coord


class PageHeader(UbuntuUIToolkitCustomProxyObjectBase):

    def go_back(self):
        """Press the back button on the header."""
        self.pointing_device.click_object(self._get_back_button())
        self.wait_until_not_moving()

    def _get_back_button(self):
        """
        Return the currently visible back button.

        There could be many back buttons available, select the one nearest
        the top of the screen.
        :return: PageHeadButton representing the back button

        """
        buttons = self.select_many(
            'PageHeadButton', objectName='customBackButton')
        button = order_by_y_coord(buttons)[0]
        button.visible.wait_for(True)
        return button

    def wait_until_not_moving(self):
        """Wait until the header has stopped moving."""
        container = self.select_single(
            'QQuickFlickable', objectName='headerContainer')
        container.moving.wait_for(False)
