# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import unityclickscope

from ubuntu_system_tests.helpers.unity8 import dash


class ClickScope(unityclickscope.ClickScope, dash.GenericScopeView):

    # Just make sure that the click scope inherits the methods we haven't yet
    # merged into unity8.
    pass


class Preview(unityclickscope.Preview):

    def open(self):
        open_button = self._get_preview_button('open_click')
        self.pointing_device.click_object(open_button)

    def _get_preview_button(self, button, wait=False):
        object_name = 'button{}'.format(button)
        if wait:
            return self.wait_select_single(
                'PreviewActionButton', objectName=object_name)
        else:
            return self.select_single(
                'PreviewActionButton', objectName=object_name)

    def uninstall(self):
        uninstall_button = self._get_preview_button('uninstall_click')
        self.pointing_device.click_object(uninstall_button)
        self._click_confirm_uninstall_button()

    def _click_confirm_uninstall_button(self):
        confirm_button = self._get_preview_button(
            'confirm_uninstall', wait=True)
        self.pointing_device.click_object(confirm_button)

    def get_button_labels(self):
        buttons = self.select_many('PreviewActionButton')
        return [button.text for button in buttons]

    def wait_until_package_installed(self):
        self._get_preview_button('open_click', wait=True)
