# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import unittest
from unittest import mock

from uciconfig import options
from ucitests import fixtures

from ubuntu_system_tests import config


class ConfigBaseTestCase(unittest.TestCase):

    def setUp(self):
        super().setUp()

        # Patch the atexit.register method so nothing is executed after the
        # test exits. As we are using a tmp directory that will be removed
        # on test cleanUp, then saving the config file to that unexisting
        # location at exit would fail.
        patcher = mock.patch('atexit.register')
        patcher.start()
        self.addCleanup(patcher.stop)

        fixtures.set_uniq_cwd(self)
        fixtures.isolate_from_env(
            self, dict(HOME=self.uniq_dir, XDG_CONFIG_HOME=None))

        options.option_registry = options.OptionRegistry()

    def set_config_values(self, **kwargs):
        config_string = ''
        for option, value in kwargs.items():
            config_string += '{} = {}\n'.format(option, value)
        # Fill with dummy values the rest of options.
        for option in config.CONFIG_OPTIONS:
            if option.name not in kwargs:
                config_string += '{} = dummy\n'.format(option.name)
        # Fill with dummy temporal values
        config_string += '{} = {}\n'.format("ssh_password", "test")

        self.config_stack.store._load_from_string(config_string)
