# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import io
import os
from unittest import mock

from ubuntu_system_tests import (
    config,
    results,
    selftests
)


class ResultsTestCase(selftests.ConfigBaseTestCase):

    def setUp(self):
        super().setUp()
        self.config_stack = config.UbuntuSystemTestsStack()
        self.config_stack.store._load_from_string(
            'output_dir = {}'.format(self.uniq_dir))

    def test_convert_subunit_results_to_pyunit(self):
        artifacts_directory = results.get_artifacts_directory(
            self.config_stack)
        os.mkdir(artifacts_directory)
        pyunit_file_path = os.path.join(
            artifacts_directory, 'test-results.pyunit')
        subunit_file_path = os.path.join(
            artifacts_directory, 'test-results.subunit')
        with mock.patch('subprocess.Popen') as mock_popen:
            enter = mock_popen().__enter__()
            # Make sure that check_output and call return with no errors.
            enter.communicate = mock.Mock(return_value=(0, 'dummy'))
            enter.poll = mock.Mock(return_value=0)
            enter.wait = mock.Mock(return_value=0)

            with open(pyunit_file_path, 'w'):
                with open(subunit_file_path, 'w'):
                    results.convert_subunit_results_to_pyunit(
                        artifacts_directory)
        calls = mock_popen.call_args_list[1]
        self.assertEqual(calls[0][0],
                         ['subunit2pyunit',
                          os.path.join(artifacts_directory,
                                       'test-results.subunit')])
        self.assertEqual(calls[1]['stderr'].name,
                         os.path.join(artifacts_directory,
                                      'test-results.pyunit'))
        self.assertTrue(calls[1]['universal_newlines'])

    def test_get_artifacts_directory(self):
        artifacts_directory = results.get_artifacts_directory(
            self.config_stack)

        self.assertEqual(
            os.path.join(self.uniq_dir, 'artifacts'), artifacts_directory)

    def test_print_results_print_pyunit_file_contents(self):
        artifacts_directory = results.get_artifacts_directory(
            self.config_stack)
        os.mkdir(artifacts_directory)
        pyunit_file_path = os.path.join(
            artifacts_directory, 'test-results.pyunit')
        with open(pyunit_file_path, 'w') as test_pyunit_file:
            test_pyunit_file.write('test pyunit contents')

        with mock.patch('sys.stdout', new_callable=io.StringIO) as mock_stdout:
            results.print_results(artifacts_directory)

        self.assertEqual(
            'test pyunit contents\n', mock_stdout.getvalue())
