# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers.system_settings import (
    get_rotation_lock,
    set_rotation_lock,
)
from ubuntu_system_tests.tests import base
from autopilot.matchers import Eventually
from testtools.matchers import Equals

ROTATIONS = {
    'left_up': {'orientation': 2, 'angle': 270},
    'right_up': {'orientation': 8, 'angle': 90},
}


class RotationTestCase(base.BaseUbuntuSystemTestCase):

    def setUp(self):
        super().setUp()
        unity_proxy = self.restart_unity(fake_sensors=True)
        self.shell = unity_proxy.main_window.select_single('Shell')
        self.addCleanup(set_rotation_lock, get_rotation_lock())
        set_rotation_lock('false')
        self.sensors.set_orientation('top_up')
        self.main_view = self.launch_system_settings()
        unity_proxy.ensure_app_loaded()

    def _assert_orientation_and_angle(self, orientation, angle):
        self.assertThat(self.shell.orientation,
                        Eventually(Equals(orientation)))
        self.assertThat(self.shell.orientationAngle,
                        Eventually(Equals(angle)))

    def test_rotation_lock_unlock(self):
        """
        Check that the System Settings application rotates when
        the rotation lock is not applied, and doesn't rotate when
        it is
        """
        for rotation in ROTATIONS:
            self.sensors.set_orientation(rotation)
            # Check shell did rotate
            self._assert_orientation_and_angle(
                ROTATIONS[rotation]['orientation'],
                ROTATIONS[rotation]['angle']
            )
        self.sensors.set_orientation('top_up')
        self._assert_orientation_and_angle(1, 0)
        self.main_view.enable_orientation_lock()
        for rotation in ROTATIONS:
            self.sensors.set_orientation(rotation)
            # Check shell did not rotate
            self._assert_orientation_and_angle(1, 0)
