# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import pkg_resources

from autopilot.matchers import Eventually
from testtools.matchers import Equals

import ubuntu_system_tests
from ubuntu_system_tests.tests import base
from ubuntu_system_tests.helpers import click
from ubuntu_system_tests.helpers.unity8.dash import get_dash

# Imported to load the custom proxy objects.
import ubuntu_system_tests.helpers.unityclickscope  # NOQA


class UninstallApplicationTestCase(base.BaseUbuntuSystemTestCase):

    def test_uninstall_application(self):
        click_file_path = pkg_resources.resource_filename(
            ubuntu_system_tests.__name__, 'data/simpleclick.qa_0.1_all.click')
        self.useFixture(click.ClickPackageInstalled(click_file_path))
        self.restart_unity()
        apps_scope = get_dash().open_apps_scope()
        self.assertIn('simpleclick', apps_scope.get_applications('local'))

        preview = apps_scope.open_preview(
            'local', 'simpleclick', press_duration=3)

        self.assertTrue(apps_scope.subPageShown)
        self.assertThat(
            preview.get_button_labels,
            Eventually(Equals(['Uninstall', 'Open'])))

        preview.uninstall()

        apps_scope.subPageShown.wait_for(False)
        apps_scope.swipe_to_top()
        self.assertNotIn('simpleclick', apps_scope.get_applications('local'))
